Imports System.ComponentModel

''' <summary>einfaches Control zur Anzeige eines GraphicsPathes</summary>
Public Class Canvas : Inherits Control

    Private _TemplatePath As GraphicsPath
    Private _DrawPath As New GraphicsPath
    Private _Matrix As New Matrix

    ''' <summary>
    ''' Canvas zeigt eine auf seine Gre skalierte Kopie dieses 
    ''' GraphicsPathes an
    ''' </summary>
    <Bindable(True)> _
    Public Property TemplatePath() As GraphicsPath
        ' Das Bindable(True)-Attribut ermglicht, Databinding auch im 
        ' Form-Designer einzustellen
        Get
            Return _TemplatePath
        End Get
        Set(ByVal NewValue As GraphicsPath)
            If _TemplatePath Is NewValue Then Return
            _TemplatePath = NewValue
            ApplyChanges()
        End Set
    End Property

    Protected Overrides Sub OnSizeChanged(ByVal e As System.EventArgs)
        MyBase.OnSizeChanged(e)
        ApplyChanges()
    End Sub

    Protected Overrides Sub OnPaint( _
        ByVal e As System.Windows.Forms.PaintEventArgs)

        MyBase.OnPaint(e)
        If _TemplatePath Is Nothing Then Return
        e.Graphics.DrawPath(Pens.Red, _DrawPath)
    End Sub

    Private Sub ApplyChanges()
        ' Lege in _DrawPath eine auf meine Gre skalierte Kopie von 
        ' _TemplatePath(an)
        If _TemplatePath Is Nothing Then Return
        _Matrix.Reset()
        Dim Bounds As RectangleF = _TemplatePath.GetBounds
        Dim Sz As SizeF = MyBase.ClientSize - New Size(1, 1)
        With _TemplatePath.GetBounds
            ' ObenLinks auf Nullpunkt schieben
            _Matrix.Translate(-.X, -.Y, MatrixOrder.Append)

            ' Skalieren
            _Matrix.Scale(Sz.Width / .Width, _
                Sz.Height / .Height, MatrixOrder.Append)
        End With
        _DrawPath.Reset()
        _DrawPath.AddPath(_TemplatePath, False)
        _DrawPath.Transform(_Matrix)
        MyBase.Invalidate()
    End Sub

    Protected Overrides Sub Dispose(ByVal disposing As Boolean)
        If disposing AndAlso _DrawPath IsNot Nothing Then
            _DrawPath.Dispose()
            _Matrix.Dispose()
            _DrawPath = Nothing
        End If
        MyBase.Dispose(disposing)
    End Sub
End Class
