Public Class frmComboFeatures
    Private Pts As PointF() = New PointF() { _
        New PointF(-4, 0), New PointF(-3, -3), New PointF(0, -4), _
        New PointF(3, -3), New PointF(4, 0), New PointF(3, 3), _
        New PointF(0, 4), New PointF(-3, 3)}

    Private Sub Form_Load(ByVal sender As Object, _
        ByVal e As EventArgs) Handles Me.Load

        SetupTab1()
        SetupTab2()
    End Sub

    Private Sub SetupTab1()
        ' Die bekannteste Art eine Combo zu befllen ist wohl jeden 
        ' anzuzeigenden String einzeln hinzuzufgen
        For Each Pt As PointF In Pts
            ComboBox1.Items.Add(Pt.ToString)
        Next
        ComboBox1.SelectedIndex = 0

        ' Man kann aber einfacher die Objekte selbst hinzufgen
        ' Zustzlicher Vorteil: ber die Items-Property knnen nun nicht nur 
        ' String-Reprsantionen der Objekte abgerufen werden, sondern die 
        ' Objekte selbst.
        ' In diesem Fall bedient sich die Combobox zur Ermittlung der Anzeige 
        ' automatisch der .ToString()-Funktion der Objekte.
        For Each Pt As PointF In Pts
            ComboBox2.Items.Add(Pt)
        Next
        ComboBox2.SelectedIndex = 0

        ' ber die "DisplayMember"-Eigenschaft der Combo kann bestimmt werden,
        ' da nicht Item.ToString() dargestellt wird, sondern die spezifizierte 
        ' Eigenschaft. Hier wird Pointf.X angezeigt 
        ' (Pointf.Y dadurch ausgeblendet)
        ComboBox3.DisplayMember = "X"
        For Each Pt As PointF In Pts
            ComboBox3.Items.Add(Pt)
        Next
        ComboBox3.SelectedIndex = 0

        ' Liegen die Daten bereits in einer Auflistung vor (hier: Array), so 
        ' kann man diese gegebenenfalls direkt als DataSource angeben. Diese 
        ' Variante ist der erste Schritt zum Databinding.
        ' Vorraussetzung: Die Auflistung mu die IList- oder IList(Of T)-
        ' Schnittstelle implementieren (derlei Informationen erfhrt man im 
        ' ObjectBrowser). Zustzlich kann die Darstellung durch Angabe eines 
        ' FormatStrings beeinflut werden
        ComboBox4.DisplayMember = "Y"
        ' Zeige Zahlenwerte als Whrung an
        ComboBox4.FormatString = "c"
        ComboBox4.DataSource = Pts
    End Sub

    Private Sub SetupTab2()
        ' Hier will ich verschiedene GraphicsPathes mit Namen verknpfen. Die 
        ' Namen sollen in der Combo angezeigt werden, die Pathes im 
        ' Canvas-Control. Statt einer eigens implementierten Daten-Klasse 
        ' nehme ich mir als Name-Path-Container einfach 
        ' KeyValuePair(Of T1, T2) her 
        Dim Entries As New List(Of KeyValuePair(Of String, GraphicsPath))
        Dim GP As New GraphicsPath
        GP.AddEllipse(0, 0, 4, 4)
        Entries.Add(New KeyValuePair(Of String, GraphicsPath)("Ellipse", GP))

        GP = New GraphicsPath
        GP.AddRectangle(New Rectangle(0, 0, 4, 4))
        Entries.Add(New KeyValuePair(Of String, GraphicsPath)("Rectangle", GP))

        GP = New GraphicsPath
        GP.AddLine(0, 0, 4, 4)
        Entries.Add(New KeyValuePair(Of String, GraphicsPath)("Line", GP))

        GP = New GraphicsPath
        GP.AddLines(Pts)
        Entries.Add(New KeyValuePair(Of String, GraphicsPath)("Lines", GP))

        GP = New GraphicsPath
        GP.AddPolygon(Pts)
        Entries.Add(New KeyValuePair(Of String, GraphicsPath)("Polygon", GP))

        GP = New GraphicsPath
        GP.AddBeziers(New PointF() {Pts(0), Pts(1), Pts(7), Pts(2), Pts(5), _
            Pts(3), Pts(4)})
        Entries.Add(New KeyValuePair(Of String, GraphicsPath)("Beziers", GP))

        ' ComboBox5 wird per .DataSource-Property die Steuerung des 
        ' DataBindings bertragen, an welches Canvas1 ebenfalls angeschlossen 
        ' wird. Auf diese Weise kann ohne weiteren Code mit der Combo gewhlt 
        ' werden, was Canvas1 anzeigt.
        ComboBox5.DisplayMember = "Key"
        ComboBox5.DataSource = Entries
        Canvas1.DataBindings.Add("TemplatePath", Entries, "Value")
    End Sub
End Class
